@@ -1,15 +1,14 @@
 #!/usr/bin/env seed
 Gtk = imports.gi.Gtk;
-Gio = imports.gi.Gio;
 Multiprocessing = imports.multiprocessing;
-
+os = imports.os;
 
 var pipes = new Multiprocessing.Pipe();
 
-var child_pid = Seed.fork();
+var child_pid = os.fork();
 
 if (child_pid === 0){
-    Gtk.init(null, null);
+    Gtk.init(Seed.argv);
 
     var id = parseInt(pipes[0].read(), 10);
 
@@ -21,10 +20,10 @@ if (child_pid === 0){
     Gtk.main();
 }
 
-Gtk.init(null, null);
+Gtk.init(Seed.argv);
 
 var window = new Gtk.Window();
-window.signal.hide.connect(function () { Gtk.main_quit(); });
+window.signal.hide.connect(Gtk.main_quit);
 
 var socket = new Gtk.Socket();
 var pipe = pipes[1];
