@@ -56,14 +56,29 @@ GHashTable *file_imports;
 * Handle definition of toplevel functions in a namespace.
 * i.e. Gtk.main
 */
+
+static gboolean
+seed_gi_importer_is_init (GIFunctionInfo *info)
+{
+  if (strcmp (g_base_info_get_name ((GIBaseInfo *) info), "init"))
+    {
+      return FALSE;
+    }
+  if (g_callable_info_get_n_args ((GICallableInfo *)info) != 2)
+    return FALSE;
+  
+  return TRUE;
+}
+
 static void
 seed_gi_importer_handle_function (JSContextRef ctx,
 				  JSObjectRef namespace_ref,
 				  GIFunctionInfo *info,
 				  JSValueRef *exception)
 {
-  if (strcmp(g_base_info_get_name ((GIBaseInfo *)info), "init"))
-    seed_gobject_define_property_from_function_info (ctx, (GIFunctionInfo *) info,
+  if (!seed_gi_importer_is_init (info))
+    seed_gobject_define_property_from_function_info (ctx, 
+						     (GIFunctionInfo *) info,
 						     namespace_ref, FALSE);
   else
     {
@@ -532,7 +547,7 @@ seed_importer_handle_native_module (JSContextRef ctx,
       return module_obj;
     }
   
-  module = g_module_open (file_path, G_MODULE_BIND_LAZY);
+  module = g_module_open (file_path, 0);
   
   if (!module)
     {
@@ -804,6 +819,93 @@ seed_importer_dir_finalize (JSObjectRef dir)
 }
 
 
+void
+seed_importer_add_global(JSObjectRef global,
+			 gchar *name)
+{
+  JSValueProtect (eng->context, global);
+  g_hash_table_insert (file_imports, seed_importer_canonicalize_path (name), global);
+}
+
+static void
+seed_importer_dir_enumerate_properties (JSContextRef ctx,
+					JSObjectRef object,
+					JSPropertyNameAccumulatorRef propertyNames)
+{
+  const gchar *entry;
+  GDir *dir;
+  GError *e = NULL;
+  gchar *path = JSObjectGetPrivate (object);
+
+  
+  dir = g_dir_open (path, 0, &e);
+  if (e)
+    {
+      SEED_NOTE(IMPORTER, "Error in g_dir_open in seed_importer_enumerate_dir_properties: %s", e->message);
+      g_error_free (e);
+      // Not much we can do here.
+      return;
+    }
+  
+  while ((entry = g_dir_read_name (dir)))
+    {
+      JSStringRef jname;
+      
+      jname = JSStringCreateWithUTF8CString (entry);
+      JSPropertyNameAccumulatorAddName (propertyNames, jname);
+      JSStringRelease (jname);
+    }
+  g_dir_close (dir);
+}
+
+JSObjectRef
+seed_importer_construct_dir (JSContextRef ctx,
+			     JSObjectRef constructor,
+			     size_t argumentCount,
+			     const JSValueRef arguments[],
+			     JSValueRef *exception)
+{
+  gchar *path;
+  if (argumentCount != 1)
+    {
+      seed_make_exception (ctx, exception, "ArgumentError",
+			   "Directory constructor expects 1 argument");
+      return (JSObjectRef)JSValueMakeUndefined (ctx);
+    }
+  path = seed_value_to_string (ctx, arguments[0], exception);
+  
+  if (!g_file_test (path, G_FILE_TEST_IS_DIR))
+    {
+      seed_make_exception (ctx, exception, "ArgumentError",
+			   "Path (%s) is not a directory", path);
+      g_free (path);
+      return (JSObjectRef)JSValueMakeUndefined (ctx);
+    }
+  
+  return JSObjectMake (ctx, importer_dir_class, path);
+}
+
+void 
+seed_importer_set_search_path(JSContextRef ctx,
+			      gchar **search_path)
+{
+  JSObjectRef imports, array;
+  JSValueRef *array_elem;
+  guint length = g_strv_length (search_path), i;
+  
+  array_elem = g_alloca (length * sizeof (array_elem));
+  imports = (JSObjectRef) seed_object_get_property (ctx, JSContextGetGlobalObject (ctx), "imports");
+  
+  for (i = 0; i < length; i++)
+    {
+      array_elem[i] = seed_value_from_string (ctx, search_path[i], NULL);
+    }
+  
+  array = JSObjectMakeArray (ctx, length, array_elem, NULL);
+  seed_object_set_property (ctx, imports, "searchPath", array);  
+  
+}
+
 JSClassDefinition importer_class_def = {
   0,				/* Version, always 0 */
   0,
@@ -857,46 +959,18 @@ JSClassDefinition importer_dir_class_def = {
   seed_importer_dir_get_property,	/* Get Property */
   NULL,				/* Set Property */
   NULL,				/* Delete Property */
-  NULL,				/* Get Property Names */
+  seed_importer_dir_enumerate_properties,				/* Get Property Names */
   NULL,				/* Call As Function */
   NULL,	/* Call As Constructor */
   NULL,				/* Has Instance */
   NULL				/* Convert To Type */
 };
 
-void
-seed_importer_add_global(JSObjectRef global,
-			 gchar *name)
-{
-  JSValueProtect (eng->context, global);
-  g_hash_table_insert (file_imports, seed_importer_canonicalize_path (name), global);
-}
-
-void 
-seed_importer_set_search_path(JSContextRef ctx,
-			      gchar **search_path)
-{
-  JSObjectRef imports, array;
-  JSValueRef *array_elem;
-  guint length = g_strv_length (search_path), i;
-  
-  array_elem = g_alloca (length * sizeof (array_elem));
-  imports = (JSObjectRef) seed_object_get_property (ctx, JSContextGetGlobalObject (ctx), "imports");
-  
-  for (i = 0; i < length; i++)
-    {
-      array_elem[i] = seed_value_from_string (ctx, search_path[i], NULL);
-    }
-  
-  array = JSObjectMakeArray (ctx, length, array_elem, NULL);
-  seed_object_set_property (ctx, imports, "searchPath", array);  
-  
-}
-
-
 void seed_initialize_importer(JSContextRef ctx,
 			      JSObjectRef global)
 {
+  JSObjectRef dir_constructor;
+
   importer_class = JSClassCreate (&importer_class_def);
   importer = JSObjectMake (ctx, importer_class, NULL);
   
@@ -911,6 +985,11 @@ void seed_initialize_importer(JSContextRef ctx,
   
   gi_imports = g_hash_table_new (g_str_hash, g_str_equal);
   file_imports = g_hash_table_new (g_str_hash, g_str_equal);
+  
+  /* Passing nonnull for class requires a webkit fix that most people wont have yet. It also has minimal benefit */
+  //  dir_constructor = JSObjectMakeConstructor (ctx, importer_dir_class, seed_importer_construct_dir);
+  dir_constructor = JSObjectMakeConstructor (ctx, NULL, seed_importer_construct_dir);
+  seed_object_set_property (ctx, importer, "Directory", dir_constructor);
 					     
   seed_object_set_property (ctx, global, "imports", importer);
 }
