@@ -78,10 +78,13 @@ SeedEngine *seed_init (gint *argc, gchar ***argv);
 SeedEngine *seed_init_with_context_group (gint *argc, gchar ***argv,
 					  SeedContextGroup group);
 
-SeedValue seed_simple_evaluate (SeedContext ctx, gchar * source, SeedException *exception);
+SeedValue seed_simple_evaluate (SeedContext ctx, 
+				gchar * source, 
+				SeedException *exception);
 
 SeedScript *seed_make_script (SeedContext ctx,
-			      const gchar * js, const gchar * source_url,
+			      const gchar * js, 
+			      const gchar * source_url,
 			      gint line_number);
 SeedScript *seed_script_new_from_file (SeedContext ctx, gchar * file);
 SeedException seed_script_exception (SeedScript * s);
@@ -233,16 +236,17 @@ SeedValue seed_value_from_object (SeedContext ctx,
 
 gpointer seed_pointer_get_pointer (SeedContext ctx, SeedValue pointer);
 
-typedef void (*SeedFunctionCallback) (SeedContext ctx,
-				      SeedObject function,
-				      SeedObject this_object,
-				      gsize argument_count,
-				      const SeedValue arguments[],
-				      SeedException * exception);
+typedef SeedValue (*SeedFunctionCallback) (SeedContext ctx,
+					   SeedObject function,
+					   SeedObject this_object,
+					   gsize argument_count,
+					   const SeedValue arguments[],
+					   SeedException * excecption);
 
 void seed_create_function (SeedContext ctx,
 			   gchar * name, SeedFunctionCallback callback,
 			   SeedObject object);
+SeedObject seed_make_function (SeedContext ctx, SeedFunctionCallback callback, const gchar *name);
 /* Inconsistent naming? */
 SeedObject seed_make_array (SeedContext ctx, const SeedValue elements,
 			    gsize num_elements, SeedException *exception);
@@ -411,5 +415,12 @@ seed_closure_warn_exception (GClosure *c, SeedContext ctx, SeedException excepti
 SeedObject
 seed_object_get_prototype (SeedContext ctx, SeedObject obj);
 
+gboolean
+seed_object_is_of_class (SeedContext ctx, SeedObject obj, SeedClass class);
+
+gboolean
+seed_value_to_format (SeedContext,
+		      const gchar *format,
+		      ...);
 
 #endif
